diff src/eval.c @ 453:3ffdc64af1e5 v7.0120

updated for version 7.0120
author vimboss
date Sat, 30 Jul 2005 22:45:36 +0000
parents 3709cf52b9b5
children 3b705e71c7b0
line wrap: on
line diff
--- a/src/eval.c
+++ b/src/eval.c
@@ -1405,7 +1405,8 @@ call_vim_function(func, argc, argv, safe
 }
 
 /*
  * Call some vimL function and return the result as a string
  * Uses argv[argc] for the function arguments.
  */
     void *
@@ -1416,20 +1417,43 @@ call_func_retstr(func, argc, argv, safe)
     int		safe;		/* use the sandbox */
 {
     typval_T	rettv;
-    char_u	*retval = NULL;
+    char_u	*retval;
 
     if (call_vim_function(func, argc, argv, safe, &rettv) == FAIL)
 	return NULL;
 
     retval = vim_strsave(get_tv_string(&rettv));
-
     clear_tv(&rettv);
-
     return retval;
 }
 
-/*
- * Call some vimL function and return the result as a list
+#if defined(FEAT_COMPL_FUNC) || defined(PROTO)
+/*
+ * Call vimL function "func" and return the result as a number.
+ * Returns -1 when calling the function fails.
+ * Uses argv[argc] for the function arguments.
+ */
+    long
+call_func_retnr(func, argc, argv, safe)
+    char_u      *func;
+    int		argc;
+    char_u      **argv;
+    int		safe;		/* use the sandbox */
+{
+    typval_T	rettv;
+    long	retval;
+
+    if (call_vim_function(func, argc, argv, safe, &rettv) == FAIL)
+	return -1;
+
+    retval = get_tv_number_chk(&rettv, NULL);
+    clear_tv(&rettv);
+    return retval;
+}
+#endif
+
+/*
+ * Call vimL function "func" and return the result as a list
  * Uses argv[argc] for the function arguments.
  */
     void *
@@ -1405,7 +1405,8 @@ call_vim_function(func, argc, argv, safe
 
 /*
- * Call some vimL function and return the result as a string
+ * Call vimL function "func" and return the result as a string.
+ * Returns NULL when calling the function fails.
  * Uses argv[argc] for the function arguments.
  */